==> slang_retail_assistant-5.1.1.tar.gz: lib/src/order_info.dart <==
part of slang_retail_assistant;

enum CancelConfirmationStatus { UNKNOWN, CONFIRMED, DENIED }
enum Action { VIEW, CANCEL }

class OrderInfo {
  int? _mIndex;
  CancelConfirmationStatus? _mCancelConfirmationStatus;
  Action? _mAction;

  int? get index => _mIndex;

  CancelConfirmationStatus? get cancelConfirmationStatus =>
      _mCancelConfirmationStatus;

  Action? get action => _mAction;

  OrderInfo._(Map<dynamic, dynamic>? map) {
    if (map == null) return;
    if (map["index"] != null) {
      _mIndex = map["index"];
    }
    if (map["cancelConfirmationStatus"] != null) {
      _mCancelConfirmationStatus =
          _cancelConfirmationStatusFromString(map["cancelConfirmationStatus"]);
    }
    if (map["action"] != null) {
      _mAction = _actionFromString(map["action"]);
    }
  }

  Map toJson() => {
        'index': _mIndex,
        'cancelConfirmationStatus':
            stringFromCancelConfirmationStatus(_mCancelConfirmationStatus!),
        'action': stringFromAction(_mAction!),
      };

  CancelConfirmationStatus _cancelConfirmationStatusFromString(
      String statusString) {
    switch (statusString) {
      case "UNKNOWN":
        return CancelConfirmationStatus.UNKNOWN;
      case "CONFIRMED":
        return CancelConfirmationStatus.CONFIRMED;
      case "DENIED":
        return CancelConfirmationStatus.DENIED;
      default:
        return CancelConfirmationStatus.UNKNOWN;
    }
  }

  Action _actionFromString(String actionString) {
    switch (actionString) {
      case "VIEW":
        return Action.VIEW;
      case "CANCEL":
        return Action.CANCEL;
      default:
        return Action.VIEW;
    }
  }

  String stringFromAction(Action action) {
    switch (action) {
      case Action.VIEW:
        return "VIEW";
      case Action.CANCEL:
        return "CANCEL";
    }
  }

  String stringFromCancelConfirmationStatus(
      CancelConfirmationStatus cancelConfirmationStatus) {
    switch (cancelConfirmationStatus) {
      case CancelConfirmationStatus.UNKNOWN:
        return "UNKNOWN";
      case CancelConfirmationStatus.CONFIRMED:
        return "CONFIRMED";
      case CancelConfirmationStatus.DENIED:
        return "DENIED";
    }
  }
}

==> slang_retail_assistant-6.0.1.tar.gz: lib/src/order_info.dart <==
part of slang_retail_assistant;

enum CancelConfirmationStatus { UNKNOWN, CONFIRMED, DENIED }
enum OrderManagementAction { VIEW, CANCEL }

class OrderInfo {
  int? _mIndex;
  CancelConfirmationStatus? _mCancelConfirmationStatus;
  OrderManagementAction? _mAction;

  int? get index => _mIndex;

  CancelConfirmationStatus? get cancelConfirmationStatus =>
      _mCancelConfirmationStatus;

  OrderManagementAction? get action => _mAction;

  OrderInfo._(Map<dynamic, dynamic>? map) {
    if (map == null) return;
    if (map["index"] != null) {
      _mIndex = map["index"];
    }
    if (map["cancelConfirmationStatus"] != null) {
      _mCancelConfirmationStatus =
          _cancelConfirmationStatusFromString(map["cancelConfirmationStatus"]);
    }
    if (map["action"] != null) {
      _mAction = _actionFromString(map["action"]);
    }
  }

  Map toJson() => {
        'index': _mIndex,
        'cancelConfirmationStatus':
            stringFromCancelConfirmationStatus(_mCancelConfirmationStatus!),
        'action': stringFromAction(_mAction!),
      };

  CancelConfirmationStatus _cancelConfirmationStatusFromString(
      String statusString) {
    switch (statusString) {
      case "UNKNOWN":
        return CancelConfirmationStatus.UNKNOWN;
      case "CONFIRMED":
        return CancelConfirmationStatus.CONFIRMED;
      case "DENIED":
        return CancelConfirmationStatus.DENIED;
      default:
        return CancelConfirmationStatus.UNKNOWN;
    }
  }

  OrderManagementAction _actionFromString(String actionString) {
    switch (actionString) {
      case "VIEW":
        return OrderManagementAction.VIEW;
      case "CANCEL":
        return OrderManagementAction.CANCEL;
      default:
        return OrderManagementAction.VIEW;
    }
  }

  String stringFromAction(OrderManagementAction action) {
    switch (action) {
      case OrderManagementAction.VIEW:
        return "VIEW";
      case OrderManagementAction.CANCEL:
        return "CANCEL";
    }
  }

  String stringFromCancelConfirmationStatus(
      CancelConfirmationStatus cancelConfirmationStatus) {
    switch (cancelConfirmationStatus) {
      case CancelConfirmationStatus.UNKNOWN:
        return "UNKNOWN";
      case CancelConfirmationStatus.CONFIRMED:
        return "CONFIRMED";
      case CancelConfirmationStatus.DENIED:
        return "DENIED";
    }
  }
}
